@@ -182,7 +182,7 @@ void StatisticsMainWindow::languagesChanged()
     Prefs::setLearningLanguage(learningLanguage);
     Prefs::setKnownLanguage(knownLanguage);
 
-    emit languagesChanged(knownLanguage, learningLanguage);
+    Q_EMIT languagesChanged(knownLanguage, learningLanguage);
 
     updateVisibleColumns();
     updateModelSettings();
@@ -322,3 +322,5 @@ void StatisticsMainWindow::updateModelSettings()
     m_statisticsModel->updateDocumentSettings();
     m_ui->lessonStatistics->restoreExpandedStatus();
 }
+
+#include "moc_statisticsmainwindow.cpp"
